<?php

	require_once( dirname(__FILE__) . "/config_bouclelibre.php" );
	
	class CnxlibreStatique {
		
		protected static $instance;
		
		protected $listeBases;
	
		protected function __construct() {
			
			$listeBases = listeBasesBouclelibre();
			
			$this->listeBases = array();
			
			if ( is_array( $listeBases ) ) {
			
				if ( count( $listeBases ) > 0 ) {
				
					foreach ( $listeBases as $libelle => $base ) {
					
						$objPDO = new PDO(
							'mysql:host=' . $base['hote'] . ';port=' . $base['port'] . ';dbname=' . $base['base'] , 
							$base['utilisateur'] , 
							$base['mdp'] , 
							array( PDO::MYSQL_ATTR_INIT_COMMAND => "SET NAMES utf8" ) 
						);
						
						$objCnxLibre = new Cnxlibre( $objPDO );
						
						$this->listeBases[$libelle] = $objCnxLibre;
					}
				}
			}
		}
		
		public function getCnx( $libelleBase = 'thelia' ) {
			
			if ( isset( $this->listeBases[$libelleBase] ) ) {
			
				return $this->listeBases[$libelleBase];
			}
			
			return false;
		}
		
		public static function getInstance() {
			
			if ( is_null( self::$instance ) ) {
			
				self::$instance = new CnxlibreStatique();
			}
			
			return self::$instance;
		}
		
		public static function getBase( $libelleBase = 'thelia' ) {
		
			$objCnxlibreStatique = self::getInstance();
			
			return $objCnxlibreStatique->getCnx( $libelleBase );
		}
	}

	class Cnxlibre {

		protected $objPDO;
		protected $objRequest;
		
		public function __construct( $objPDO ) {
		
			$this->objPDO = $objPDO;
		}
		
		//	Chaque occurence est un tableau associatif
		public function listeTableaux( $sql , $values = array() ) {
		
			$this->objRequest = $this->objPDO->prepare( $sql );
			$this->objRequest->execute( $values );
			
			$lignes = $this->objRequest->fetchAll( PDO::FETCH_ASSOC );
			return $lignes;
		}
		
		//	Chaque occurence est une instance de la classe spécifiée en paramètre
		public function listeInstances( $sql , $valeurs = array() , $nomClasse = "stdClass" ) {
		
			$this->objRequest = $this->objPDO->prepare( $sql );
			$this->objRequest->execute( $valeurs );
			
			$instances = $this->objRequest->fetchAll( PDO::FETCH_CLASS , $nomClasse );
			return $instances;
		}
		
		//	Renvoit une occurence de la classe spécifiée en paramètre
		public function uneInstance( $sql , $valeurs = array() , $nomClasse = "stdClass" ){
		
			$this->objRequest = $this->objPDO->prepare( $sql );
			$this->objRequest->execute( $valeurs );
			
			$instance = $this->objRequest->fetchObject( $nomClasse );
			return $instance;
		}
		
		//	Exécute un UPDATE / INSERT / DELETE
		public function majDonnees( $sqlRequest , $values = array() ){
		
			$valide = false;
			
			$this->objRequest = $this->objPDO->prepare( $sqlRequest );
			if ( $this->objRequest->execute( $values ) ) {
			
				$valide = true;
			}
			
			return $valide;
		}
		
		
		public function sqlPrepare( $sqlRequest ) {
		
			$this->objRequest = $this->objPDO->prepare( $sqlRequest );
		}
		
		public function sqlExecute( $values ) {
		
			$this->objRequest->execute( $values );
			
			$lignes = $this->objRequest->fetchAll();
			return $lignes;
		}
		
		//	Pour les courageux
		public function close() {
		
			$this->objRequest->closeCursor();
		}
		
		//	Renvoit le dernier identifiant inséré dans la table spécifiée en paramètre
		public function dernierIdInsere( $table ) {
		
			return $this->objPDO->lastInsertId( $table );
		}
		
		//	Détermine si la table contient des éléments
		public function tableEstVide( $table ) {
		
			$sql = "
				SELECT
					*
				FROM
					`" . $table . "`
				LIMIT 
					0,1
			";
			$tableEstVide = true;
			foreach ( $this->sqlEngine( $sql ) as $ligne ) {
			
				$tableEstVide = false;
			}
			
			return $tableEstVide;
		}
		
		public function listeColonnes( $table ) {
			
			$listeColonnes = array();
			
			$sql = "
				SHOW 
					columns
				FROM
					`" . $table . "`
			";
			
			foreach ( $this->listeTableaux( $sql ) as $infosColonne ) {
				
				if ( isset( $infosColonne['Field'] ) ) {
				
					$listeColonnes[] = $infosColonne['Field'];
				}
			}
			
			return $listeColonnes;
		}
	}
	
